==> 1.0.2.tar.gz: lib/src/shared/model/meta/device_meta_model.dart <==
class DeviceMeta {
  final String os;
  final String osVersion;
  final String applicationid;
  final String versionNum;
  final String versionCode;
  final String flavor;
  final String width;
  final String height;
  final String density;
  final String densityDpi;
  final String orientation;
  final String locale;
  final String latitude;
  final String longitude;
  final String batteryLevel;
  final String batteryTemp;
  final String network;
  final String connectedToNetwork;
  final String deviceId;
  final String carrier;
  final String ram;
  final String internalMemTotal;
  final String internalMemAvail;
  final String sessionId;
  final String brand;
  final String device;
  final String deviceType;

  DeviceMeta({
    required this.os,
    required this.osVersion,
    required this.applicationid,
    required this.versionNum,
    required this.versionCode,
    required this.flavor,
    required this.width,
    required this.height,
    required this.density,
    required this.densityDpi,
    required this.orientation,
    required this.locale,
    required this.latitude,
    required this.longitude,
    required this.batteryLevel,
    required this.batteryTemp,
    required this.network,
    required this.connectedToNetwork,
    required this.deviceId,
    required this.carrier,
    required this.ram,
    required this.internalMemTotal,
    required this.internalMemAvail,
    required this.sessionId,
    required this.brand,
    required this.device,
    required this.deviceType,
  });

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['os'] = this.os;
    data['osVersion'] = this.osVersion;
    data['applicationid'] = this.applicationid;
    data['versionNum'] = this.versionNum;
    data['versionCode'] = this.versionCode;
    data['flavor'] = this.flavor;
    data['width'] = this.width;
    data['height'] = this.height;
    data['density'] = this.density;
    data['densityDpi'] = this.densityDpi;
    data['orientation'] = this.orientation;
    data['locale'] = this.locale;
    data['latitude'] = this.latitude;
    data['longitude'] = this.longitude;
    data['batteryLevel'] = this.batteryLevel;
    data['batteryTemp'] = this.batteryTemp;
    data['network'] = this.network;
    data['connectedToNetwork'] = this.connectedToNetwork;
    data['deviceId'] = this.deviceId;
    data['carrier'] = this.carrier;
    data['ram'] = this.ram;
    data['internalMemTotal'] = this.internalMemTotal;
    data['internalMemAvail'] = this.internalMemAvail;
    data['sessionId'] = this.sessionId;
    data['brand'] = this.brand;
    data['device'] = this.device;
    data['deviceType'] = this.deviceType;
    return data;
  }
}

==> 1.0.6.tar.gz: lib/src/shared/model/meta/device_meta_model.dart <==
class DeviceMeta {
  final String os;
  final String osVersion;
  final String applicationid;
  final String versionNum;
  final String versionCode;
  final String flavor;
  final String width;
  final String height;
  final String density;
  final String densityDpi;
  final String orientation;
  final String locale;
  final String latitude;
  final String longitude;
  final String batteryLevel;
  final String batteryTemp;
  final String network;
  final bool connectedToNetwork;
  final String deviceId;
  final String carrier;
  final String ram;
  final String internalMemTotal;
  final String internalMemAvail;
  final String sessionId;
  final String brand;
  final String device;
  final String deviceType;

  DeviceMeta({
    required this.os,
    required this.osVersion,
    required this.applicationid,
    required this.versionNum,
    required this.versionCode,
    required this.flavor,
    required this.width,
    required this.height,
    required this.density,
    required this.densityDpi,
    required this.orientation,
    required this.locale,
    required this.latitude,
    required this.longitude,
    required this.batteryLevel,
    required this.batteryTemp,
    required this.network,
    required this.connectedToNetwork,
    required this.deviceId,
    required this.carrier,
    required this.ram,
    required this.internalMemTotal,
    required this.internalMemAvail,
    required this.sessionId,
    required this.brand,
    required this.device,
    required this.deviceType,
  });

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['os'] = this.os;
    data['osVersion'] = this.osVersion;
    data['applicationid'] = this.applicationid;
    data['versionNum'] = this.versionNum;
    data['versionCode'] = this.versionCode;
    data['flavor'] = this.flavor;
    data['width'] = this.width;
    data['height'] = this.height;
    data['density'] = this.density;
    data['densityDpi'] = this.densityDpi;
    data['orientation'] = this.orientation;
    data['locale'] = this.locale;
    data['latitude'] = this.latitude;
    data['longitude'] = this.longitude;
    data['batteryLevel'] = this.batteryLevel;
    data['batteryTemp'] = this.batteryTemp;
    data['network'] = this.network;
    data['connectedToNetwork'] = this.connectedToNetwork;
    data['deviceId'] = this.deviceId;
    data['carrier'] = this.carrier;
    data['ram'] = this.ram;
    data['internalMemTotal'] = this.internalMemTotal;
    data['internalMemAvail'] = this.internalMemAvail;
    data['sessionId'] = this.sessionId;
    data['brand'] = this.brand;
    data['device'] = this.device;
    data['deviceType'] = this.deviceType;
    return data;
  }
}
